Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
// AddMetricSuffixes controls whether suffixes are added to metric names. Defaults to true.
AddMetricSuffixes bool `mapstructure:"add_metric_suffixes"`
// ExtraMetricsConfig configures the target_info and otel_scope_info metrics.
ExtraMetricsConfig ExtraMetricsConfig `mapstructure:"extra_metrics_config"`
// DestinationProjectQuota enables per-request usage of the destination project's quota.
DestinationProjectQuota bool `mapstructure:"destination_project_quota"`
}
Config provides configuration options specific to the GMP translation. It is meant to be embedded in the googlemanagedprometheus configuration.
func DefaultConfig ¶ added in v0.43.0
func DefaultConfig() Config
func (Config) ExtraMetrics ¶ added in v0.43.0
func (Config) MapToPrometheusTarget ¶ added in v0.43.0
func (c Config) MapToPrometheusTarget(res pcommon.Resource) *monitoredrespb.MonitoredResource
type ExtraMetricsConfig ¶ added in v0.43.0
type ExtraMetricsConfig struct {
// Add `target_info` metric based on the resource. On by default.
EnableTargetInfo bool `mapstructure:"enable_target_info"`
// Add `otel_scope_info` metric and `scope_name`/`scope_version` attributes to all other metrics. On by default.
EnableScopeInfo bool `mapstructure:"enable_scope_info"`
}
ExtraMetricsConfig controls the inclusion of additional metrics.
Click to show internal directories.
Click to hide internal directories.